pub struct SyncWrapper<T, E>{ /* private fields */ }This module has been deprecated in favor of the dedicated deadpool-sync utility crate.
Wrapper for objects which only provides blocking functions that need to be called on a separate thread.
Access to the wrapped object is provided via the SyncWrapper::interact()
method.
Implementations
Sourceimpl<T, E> SyncWrapper<T, E>
impl<T, E> SyncWrapper<T, E>
Sourcepub async fn new<F>(runtime: Runtime, f: F) -> Result<Self, E>
👎Deprecated since 0.9.1: This module has been deprecated in favor of the dedicated deadpool-sync utility crate.
pub async fn new<F>(runtime: Runtime, f: F) -> Result<Self, E>
This module has been deprecated in favor of the dedicated deadpool-sync utility crate.
Creates a new wrapped object.
Sourcepub async fn interact<F, R>(&self, f: F) -> Result<R, InteractError<E>>
👎Deprecated since 0.9.1: This module has been deprecated in favor of the dedicated deadpool-sync utility crate.
pub async fn interact<F, R>(&self, f: F) -> Result<R, InteractError<E>>
This module has been deprecated in favor of the dedicated deadpool-sync utility crate.
Interacts with the underlying object.
Expects a closure that takes the object as its parameter. The closure is executed in a separate thread so that the async runtime is not blocked.
Sourcepub fn is_mutex_poisoned(&self) -> bool
👎Deprecated since 0.9.1: This module has been deprecated in favor of the dedicated deadpool-sync utility crate.
pub fn is_mutex_poisoned(&self) -> bool
This module has been deprecated in favor of the dedicated deadpool-sync utility crate.
Indicates whether the underlying Mutex has been poisoned.
This happens when a panic occurs while interacting with the object.
Sourcepub fn lock(
&self,
) -> Result<SyncGuard<'_, T>, PoisonError<MutexGuard<'_, Option<T>>>>
👎Deprecated since 0.9.1: This module has been deprecated in favor of the dedicated deadpool-sync utility crate.
pub fn lock( &self, ) -> Result<SyncGuard<'_, T>, PoisonError<MutexGuard<'_, Option<T>>>>
This module has been deprecated in favor of the dedicated deadpool-sync utility crate.
Lock the underlying mutex and return a guard for the inner object.
Sourcepub fn try_lock(
&self,
) -> Result<SyncGuard<'_, T>, TryLockError<MutexGuard<'_, Option<T>>>>
👎Deprecated since 0.9.1: This module has been deprecated in favor of the dedicated deadpool-sync utility crate.
pub fn try_lock( &self, ) -> Result<SyncGuard<'_, T>, TryLockError<MutexGuard<'_, Option<T>>>>
This module has been deprecated in favor of the dedicated deadpool-sync utility crate.
Try to lock the underlying mutex and return a guard for the inner object.